==> sslexplorer-0.2.13-src.tar.gz: sslexplorer-0.2.13/sslexplorer/src/com/sslexplorer/core/ThemesMultiSelectListDataSource.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.core;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.util.LabelValueBean;

import com.sslexplorer.input.MultiSelectDataSource;
import com.sslexplorer.security.SessionInfo;

public class ThemesMultiSelectListDataSource implements MultiSelectDataSource {
    
    final static Log log = LogFactory.getLog(ThemesMultiSelectListDataSource.class);
    
    public ThemesMultiSelectListDataSource() {
    }

    public List getValues(SessionInfo session) {
        ArrayList l = new ArrayList();
        l.add(new LabelValueBean("Default", "/theme/default"));
        return l;
    }
}

==> sslexplorer-0.2.15_01-src.tar.gz: sslexplorer-0.2.15_01/sslexplorer/src/com/sslexplorer/core/ThemesMultiSelectListDataSource.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.core;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.util.LabelValueBean;

import com.sslexplorer.input.MultiSelectDataSource;
import com.sslexplorer.security.SessionInfo;

public class ThemesMultiSelectListDataSource implements MultiSelectDataSource {
    
    final static Log log = LogFactory.getLog(ThemesMultiSelectListDataSource.class);
    
    public ThemesMultiSelectListDataSource() {
    }

    public Collection<LabelValueBean> getValues(SessionInfo session) {
        ArrayList l = new ArrayList();
        l.add(new LabelValueBean("Default", "/theme/default"));
        return l;
    }
}
